@@ -1,5 +1,5 @@
-from lobotomy._services._definitions import Method  # noqa
-from lobotomy._services._definitions import Service  # noqa
+from lobotomy._services._definitions import Method  # noqa: F401
+from lobotomy._services._definitions import Service  # noqa: F401
 
 
 def load_definition(service_name: str) -> "Service":
